.. pycalphad documentation master file, created by
   sphinx-quickstart on Sat Apr 11 16:58:12 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. |logo| image:: pycalphad-logo-notext.png
          :height: 20pt
          :width: 20pt
          :alt: Logo

|logo| pycalphad: Computational Thermodynamics
==============================================

.. figure:: AlNi.png
    :width: 565px
    :align: center
    :height: 416px
    :alt: Al-Ni Phase Diagram (Dupin et al., 2001)
    :figclass: align-center


pycalphad is a Python library for computational thermodynamics using the CALPHAD method.

The latest development version of the source code can be found on `GitHub`_.
The newest stable version can be found on `PyPI`_.

.. _GitHub: https://github.com/pycalphad/pycalphad
.. _PyPI: https://pypi.python.org/pypi/pycalphad

.. toctree::
   :maxdepth: 2

   INSTALLING
   examples/index
   faq
   CHANGES


.. toctree::
   :maxdepth: 1
   :caption: Developer

   releasing
   onboarding
   api/modules

Getting Help
============

Questions about installing and using pycalphad can be addressed in the `pycalphad Google Group`_.
Technical issues and bugs should be reported on on `GitHub`_.
A public chat channel is available on `Gitter`_.

.. _Gitter: https://gitter.im/pycalphad/pycalphad
.. _pycalphad Google Group: https://groups.google.com/d/forum/pycalphad

Citing
======

If you use pycalphad in your research, please consider citing the following work:

Otis, R. & Liu, Z.-K., (2017). pycalphad: CALPHAD-based Computational Thermodynamics in Python. Journal of Open Research Software. 5(1), p.1. DOI: http://doi.org/10.5334/jors.140


Acknowledgements
================
Development has been made possible in part through NASA Space Technology Research Fellowship (NSTRF) grant NNX14AL43H, and is supervised by `Prof. Zi-Kui Liu`_ in the `Department of Materials Science and Engineering`_ at the `Pennsylvania State University`_.

.. _Prof. Zi-Kui Liu: http://www.phases.psu.edu/
.. _Department of Materials Science and Engineering: http://matse.psu.edu/
.. _Pennsylvania State University: http://www.psu.edu/

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
